@@ -1,5 +1,5 @@
 /*
-% Copyright (C) 2003-2015 GraphicsMagick Group
+% Copyright (C) 2003-2020 GraphicsMagick Group
 % Copyright (C) 2002 ImageMagick Studio
 %
 % This program is covered by multiple licenses, which are described in
@@ -228,7 +228,7 @@ static unsigned int WriteMPEGParameterFiles(const ImageInfo *image_info,
   register long
     i;
 
-  static int
+  static const int
     q_matrix[]=
     {
        8, 16, 19, 22, 26, 27, 29, 34,
@@ -247,6 +247,11 @@ static unsigned int WriteMPEGParameterFiles(const ImageInfo *image_info,
   unsigned long
     count;
 
+  assert(image_info != (const ImageInfo *) NULL);
+  assert(image_info->signature == MagickSignature);
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+
   /*
     Write parameter file (see mpeg2encode documentation for details).
   */
@@ -313,7 +318,7 @@ static unsigned int WriteMPEGParameterFiles(const ImageInfo *image_info,
           file=(FILE *) NULL;
           return(False);
         }
-      q=Min(Max(66.0-(2*image_info->quality)/3.0,1.0),255);
+      q=Min(Max(66.0-(2.0*image_info->quality)/3.0,1.0),255.0);
       for (i=0; i < 64; i++)
       {
         (void) fprintf(parameter_file," %d",(int) q);
@@ -488,7 +493,7 @@ static unsigned int WriteMPEGImage(const ImageInfo *image_info,Image *image)
   */
   if(!AcquireTemporaryFileName(basename))
     {
-      DestroyImage(coalesce_image);
+      DestroyImageList(coalesce_image);
       ThrowWriterTemporaryFileException(basename);
     }
   FormatString(coalesce_image->filename,"%.1024s",basename);
@@ -498,7 +503,7 @@ static unsigned int WriteMPEGImage(const ImageInfo *image_info,Image *image)
   if (status == False)
     {
       if (coalesce_image != image)
-        DestroyImage(coalesce_image);
+        DestroyImageList(coalesce_image);
       (void) LiberateTemporaryFile(basename);
       if (image_info->quality != DefaultCompressionQuality)
         {
@@ -604,7 +609,7 @@ static unsigned int WriteMPEGImage(const ImageInfo *image_info,Image *image)
   (void) remove(filename);
   (void) LiberateTemporaryFile(basename);
   if (coalesce_image != image)
-    DestroyImage(coalesce_image);
+    DestroyImageList(coalesce_image);
   if (logging)
     (void) LogMagickEvent(CoderEvent,GetMagickModule(),"exit");
   return(status);
